https://www.cloudcity.io/blog/2018/11/08/parsing-logs-230x-f...
In the end I didn't use Nom for the time being, as the author said:
> While wondering if there was a way to make it faster, I started re-reading the nom docs carefully, and that’s when I noticed that “sometimes, nom can be almost as fast as regex”. Feeling pretty silly, I went and rewrote my rust program to use the regex crate, and sure enough it got 3x faster.
Nom parser library is slower than regex crate? In simple cases it might not be worth it unfortunately.